@@ -37,23 +37,23 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_iam
-import constructs
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class ManagedInstanceRole(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@renovosolutions/cdk-library-managed-instance-role.ManagedInstanceRole",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         create_instance_profile: typing.Optional[builtins.bool] = None,
         domain_join_enabled: typing.Optional[builtins.bool] = None,
-        managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.ManagedPolicy]] = None,
+        managed_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]] = None,
         retention_policy: typing.Optional[builtins.bool] = None,
         ssm_management_enabled: typing.Optional[builtins.bool] = None,
     ) -> None:
@@ -67,18 +67,7 @@ class ManagedInstanceRole(
         :param ssm_management_enabled: Should the role include SSM management. By default if domainJoinEnabled is true then this role is always included.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                create_instance_profile: typing.Optional[builtins.bool] = None,
-                domain_join_enabled: typing.Optional[builtins.bool] = None,
-                managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.ManagedPolicy]] = None,
-                retention_policy: typing.Optional[builtins.bool] = None,
-                ssm_management_enabled: typing.Optional[builtins.bool] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__83f560e4dc759ebe2ceca3b46424c095a7f4f3617f778ecd424d8a1078704302)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ManagedInstanceRoleProps(
@@ -105,15 +94,17 @@ class ManagedInstanceRole(
 
     @builtins.property
     @jsii.member(jsii_name="role")
-    def role(self) -> aws_cdk.aws_iam.Role:
+    def role(self) -> _aws_cdk_aws_iam_ceddda9d.Role:
         '''The role.'''
-        return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "role"))
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.Role, jsii.get(self, "role"))
 
     @builtins.property
     @jsii.member(jsii_name="instanceProfile")
-    def instance_profile(self) -> typing.Optional[aws_cdk.aws_iam.CfnInstanceProfile]:
+    def instance_profile(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile]:
         '''The CfnInstanceProfile automatically created for this role.'''
-        return typing.cast(typing.Optional[aws_cdk.aws_iam.CfnInstanceProfile], jsii.get(self, "instanceProfile"))
+        return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.CfnInstanceProfile], jsii.get(self, "instanceProfile"))
 
 
 @jsii.data_type(
@@ -133,7 +124,7 @@ class ManagedInstanceRoleProps:
         *,
         create_instance_profile: typing.Optional[builtins.bool] = None,
         domain_join_enabled: typing.Optional[builtins.bool] = None,
-        managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.ManagedPolicy]] = None,
+        managed_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]] = None,
         retention_policy: typing.Optional[builtins.bool] = None,
         ssm_management_enabled: typing.Optional[builtins.bool] = None,
     ) -> None:
@@ -145,22 +136,13 @@ class ManagedInstanceRoleProps:
         :param ssm_management_enabled: Should the role include SSM management. By default if domainJoinEnabled is true then this role is always included.
         '''
         if __debug__:
-            def stub(
-                *,
-                create_instance_profile: typing.Optional[builtins.bool] = None,
-                domain_join_enabled: typing.Optional[builtins.bool] = None,
-                managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.ManagedPolicy]] = None,
-                retention_policy: typing.Optional[builtins.bool] = None,
-                ssm_management_enabled: typing.Optional[builtins.bool] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__5dc346b2a1a5c2a6efa7437dd14db41986afb15e073cd0b7f07a5535dff51898)
             check_type(argname="argument create_instance_profile", value=create_instance_profile, expected_type=type_hints["create_instance_profile"])
             check_type(argname="argument domain_join_enabled", value=domain_join_enabled, expected_type=type_hints["domain_join_enabled"])
             check_type(argname="argument managed_policies", value=managed_policies, expected_type=type_hints["managed_policies"])
             check_type(argname="argument retention_policy", value=retention_policy, expected_type=type_hints["retention_policy"])
             check_type(argname="argument ssm_management_enabled", value=ssm_management_enabled, expected_type=type_hints["ssm_management_enabled"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if create_instance_profile is not None:
             self._values["create_instance_profile"] = create_instance_profile
         if domain_join_enabled is not None:
@@ -190,10 +172,10 @@ class ManagedInstanceRoleProps:
     @builtins.property
     def managed_policies(
         self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_iam.ManagedPolicy]]:
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]]:
         '''The managed policies to apply to the role in addition to the default policies.'''
         result = self._values.get("managed_policies")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_iam.ManagedPolicy]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]], result)
 
     @builtins.property
     def retention_policy(self) -> typing.Optional[builtins.bool]:
@@ -228,3 +210,27 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__83f560e4dc759ebe2ceca3b46424c095a7f4f3617f778ecd424d8a1078704302(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    create_instance_profile: typing.Optional[builtins.bool] = None,
+    domain_join_enabled: typing.Optional[builtins.bool] = None,
+    managed_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]] = None,
+    retention_policy: typing.Optional[builtins.bool] = None,
+    ssm_management_enabled: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5dc346b2a1a5c2a6efa7437dd14db41986afb15e073cd0b7f07a5535dff51898(
+    *,
+    create_instance_profile: typing.Optional[builtins.bool] = None,
+    domain_join_enabled: typing.Optional[builtins.bool] = None,
+    managed_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]] = None,
+    retention_policy: typing.Optional[builtins.bool] = None,
+    ssm_management_enabled: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
